import request from '@/utils/request'

// 查询固件版本列表
export function listOta(query) {
    return request({
        url: '/iot/ota/list',
        method: 'get',
        params: query
    })
}

// 查询固件版本详细
export function getOta(otaId) {
    return request({
        url: '/iot/ota/' + otaId,
        method: 'get'
    })
}

// 新增固件版本
export function addOta(data) {
    return request({
        url: '/iot/ota',
        method: 'post',
        data: data
    })
}

// 修改固件版本
export function updateOta(data) {
    return request({
        url: '/iot/ota',
        method: 'put',
        data: data
    })
}

// 删除固件版本
export function delOta(otaId) {
    return request({
        url: '/iot/ota/' + otaId,
        method: 'delete'
    })
}

// 导出固件版本
export function exportOta(query) {
    return request({
        url: '/iot/ota/export',
        method: 'get',
        params: query
    })
}

// 新增固件版本
export function upgradeOta(data) {
  return request({
      url: '/iot/ota/upgrade',
      method: 'post',
      data: data
  })
}
